@@ -28,6 +28,12 @@ has net_server => (
     default => undef,
 );
 
+has net_server_configure => (
+    is      => 'ro',
+    isa     => 'HashRef',
+    default => sub { +{} },
+);
+
 sub run {
     my ($self, ) = @_;
 
@@ -91,7 +97,7 @@ sub run {
             $self->port
         );
     $server->host($self->host);
-    $server->run;
+    $server->run(%{ $self->net_server_configure });
 }
 
 __INTERFACE__
@@ -108,6 +114,42 @@ HTTP::Engine::Plugin::Interface::ServerSimple is wrapper for HTTP::Server::Simpl
 
 HTTP::Server::Simple is flexible web server.And it can use Net::Server, so you can make it preforking or using Coro.
 
+=head1 ATTRIBUTES
+
+=over 4
+
+=item host
+
+=item port
+
+=item net_server
+
+User-overridable method. If you set it to a L<Net::Server> subclass, that subclass is used for the L<HTTP::Server::Simple>.
+
+=item net_server_configure
+
+Any arguments passed to this will be passed on to the underlying L<Net::Server> implementation.
+
+  # SYNOPSIS
+  my $engine = HTTP::Engine->new(
+      interface => {
+          module => 'ServerSimple',
+          args   => {
+              host => 'localhost',
+              port =>  1978,
+              net_server => 'Net::Server::PreForkSimple',
+              net_server_configure => {
+                  max_servers  => 5,
+                  max_requests => 100,
+              },
+          },
+          request_handler => 'main::handle_request',# or CODE ref
+      },
+  );
+  $engine->run;
+
+=back
+
 =head1 AUTHOR
 
 Tokuhiro Matsuno(cpan:tokuhirom)
